<?php    
/**
 *peti-care Theme Customizer
 *
 * @package Peti Care
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function peti_care_customize_register( $wp_customize ) {	
	
	function peti_care_sanitize_dropdown_pages( $page_id, $setting ) {
	  // Ensure $input is an absolute integer.
	  $page_id = absint( $page_id );	
	  // If $page_id is an ID of a published page, return it; otherwise, return the default.
	  return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
	}

	function peti_care_sanitize_checkbox( $checked ) {
		// Boolean check.
		return ( ( isset( $checked ) && true == $checked ) ? true : false );
	} 
	
	function peti_care_sanitize_phone_number( $phone ) {
		// sanitize phone
		return preg_replace( '/[^\d+]/', '', $phone );
	} 
	
	
	function peti_care_sanitize_excerptrange( $number, $setting ) {	
		// Ensure input is an absolute integer.
		$number = absint( $number );	
		// Get the input attributes associated with the setting.
		$atts = $setting->manager->get_control( $setting->id )->input_attrs;	
		// Get minimum number in the range.
		$min = ( isset( $atts['min'] ) ? $atts['min'] : $number );	
		// Get maximum number in the range.
		$max = ( isset( $atts['max'] ) ? $atts['max'] : $number );	
		// Get step.
		$step = ( isset( $atts['step'] ) ? $atts['step'] : 1 );	
		// If the number is within the valid range, return it; otherwise, return the default
		return ( $min <= $number && $number <= $max && is_int( $number / $step ) ? $number : $setting->default );
	}

	function peti_care_sanitize_number_absint( $number, $setting ) {
		// Ensure $number is an absolute integer (whole number, zero or greater).
		$number = absint( $number );		
		// If the input is an absolute integer, return it; otherwise, return the default
		return ( $number ? $number : $setting->default );
	}
	
	// Ensure is an absolute integer
	function peti_care_sanitize_choices( $input, $setting ) {
		global $wp_customize; 
		$control = $wp_customize->get_control( $setting->id ); 
		if ( array_key_exists( $input, $control->choices ) ) {
			return $input;
		} else {
			return $setting->default;
		}
	}
	
		
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	
	$wp_customize->selective_refresh->add_partial( 'blogname', array(
		'selector' => '.logo h1 a',
		'render_callback' => 'peti_care_customize_partial_blogname',
	) );
	$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
		'selector' => '.logo p',
		'render_callback' => 'peti_care_customize_partial_blogdescription',
	) );
		
	 	
	//Panel for section & control
	$wp_customize->add_panel( 'peti_care_optionspanel_settings', array(
		'priority' => 4,
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => __( 'Peti Care Theme Settings', 'peti-care' ),		
	) );

	$wp_customize->add_section('peti_care_sitelayout',array(
		'title' => __('Layout Style','peti-care'),			
		'priority' => 1,
		'panel' => 	'peti_care_optionspanel_settings',          
	));		
	
	$wp_customize->add_setting('peti_care_layoutoption',array(
		'sanitize_callback' => 'peti_care_sanitize_checkbox',
	));	 

	$wp_customize->add_control( 'peti_care_layoutoption', array(
    	'section'   => 'peti_care_sitelayout',    	 
		'label' => __('Check to Show Box Layout','peti-care'),
		'description' => __('check for box layout','peti-care'),
    	'type'      => 'checkbox'
     )); //Box Layout Options 
	
	$wp_customize->add_setting('peti_care_colorscheme',array(
		'default' => '#91c330',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(
		new WP_Customize_Color_Control($wp_customize,'peti_care_colorscheme',array(
			'label' => __('Color Scheme','peti-care'),			
			'section' => 'colors',
			'settings' => 'peti_care_colorscheme'
		))
	);
	
	$wp_customize->add_setting('peti_care_menufontcolor',array(
		'default' => '#333333',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(
		new WP_Customize_Color_Control($wp_customize,'peti_care_menufontcolor',array(
			'label' => __('Navigation font Color','peti-care'),			
			'section' => 'colors',
			'settings' => 'peti_care_menufontcolor'
		))
	);
	
	
	$wp_customize->add_setting('peti_care_menufontactivecolor',array(
		'default' => '#91c330',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(
		new WP_Customize_Color_Control($wp_customize,'peti_care_menufontactivecolor',array(
			'label' => __('Navigation Hover/Active Color','peti-care'),			
			'section' => 'colors',
			'settings' => 'peti_care_menufontactivecolor'
		))
	);
	
	 //Header Contact details
	$wp_customize->add_section('peti_care_topcontactinfo',array(
		'title' => __('Header Contact Info','peti-care'),				
		'priority' => null,
		'panel' => 	'peti_care_optionspanel_settings',
	));	
	
	
	$wp_customize->add_setting('peti_care_emailid',array(
		'sanitize_callback' => 'sanitize_email'
	));
	
	$wp_customize->add_control('peti_care_emailid',array(
		'type' => 'email',
		'label' => __('enter email id here.','peti-care'),
		'section' => 'peti_care_topcontactinfo'
	));		
		
	$wp_customize->add_setting('peti_care_facebooklink',array(
		'default' => null,
		'sanitize_callback' => 'esc_url_raw'	
	));
	
	$wp_customize->add_control('peti_care_facebooklink',array(
		'label' => __('Add facebook link here','peti-care'),
		'section' => 'peti_care_topcontactinfo',
		'setting' => 'peti_care_facebooklink'
	));	
	
	$wp_customize->add_setting('peti_care_twitterlink',array(
		'default' => null,
		'sanitize_callback' => 'esc_url_raw'
	));
	
	$wp_customize->add_control('peti_care_twitterlink',array(
		'label' => __('Add twitter link here','peti-care'),
		'section' => 'peti_care_topcontactinfo',
		'setting' => 'peti_care_twitterlink'
	));

	
	$wp_customize->add_setting('peti_care_linkedinlink',array(
		'default' => null,
		'sanitize_callback' => 'esc_url_raw'
	));
	
	$wp_customize->add_control('peti_care_linkedinlink',array(
		'label' => __('Add linkedin link here','peti-care'),
		'section' => 'peti_care_topcontactinfo',
		'setting' => 'peti_care_linkedinlink'
	));
	
	$wp_customize->add_setting('peti_care_instagramlink',array(
		'default' => null,
		'sanitize_callback' => 'esc_url_raw'
	));
	
	$wp_customize->add_control('peti_care_instagramlink',array(
		'label' => __('Add instagram link here','peti-care'),
		'section' => 'peti_care_topcontactinfo',
		'setting' => 'peti_care_instagramlink'
	));
	
	 $wp_customize->add_setting('peti_care_requestaquotebtn',array(
		'default' => null,
		'sanitize_callback' => 'sanitize_text_field'	
	));
	
	$wp_customize->add_control('peti_care_requestaquotebtn',array(	
		'type' => 'text',
		'label' => __('Enter button name here','peti-care'),
		'setting' => 'peti_care_requestaquotebtn',
		'section' => 'peti_care_topcontactinfo'
	));	
	
	$wp_customize->add_setting('peti_care_requestaquotebtnlink',array(
		'default' => null,
		'sanitize_callback' => 'esc_url_raw'
	));
	
	$wp_customize->add_control('peti_care_requestaquotebtnlink',array(
		'label' => __('Add button link here','peti-care'),		
		'setting' => 'peti_care_requestaquotebtnlink',
		'section' => 'peti_care_topcontactinfo'
	));
	
	$wp_customize->add_setting('peti_care_show_hdinfodetails',array(
		'default' => false,
		'sanitize_callback' => 'peti_care_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));	 
	
	$wp_customize->add_control( 'peti_care_show_hdinfodetails', array(
	   'settings' => 'peti_care_show_hdinfodetails',
	   'section'   => 'peti_care_topcontactinfo',
	   'label'     => __('Check To show Header contact Section','peti-care'),
	   'type'      => 'checkbox'
	 ));//Show Top Contact info Sections
	 
	 
	 $wp_customize->add_setting('peti_care_shorttextofphone',array(
		'default' => null,
		'sanitize_callback' => 'sanitize_text_field'	
	));
	
	$wp_customize->add_control('peti_care_shorttextofphone',array(	
		'type' => 'text',
		'label' => __('Enter short text here','peti-care'),
		'section' => 'peti_care_topcontactinfo',
		'setting' => 'peti_care_shorttextofphone'
	));	
	
	$wp_customize->add_setting('peti_care_slidephoneno',array(
		'default' => null,
		'sanitize_callback' => 'peti_care_sanitize_phone_number'	
	));
	
	$wp_customize->add_control('peti_care_slidephoneno',array(	
		'type' => 'text',
		'label' => __('Enter phone number here','peti-care'),
		'section' => 'peti_care_topcontactinfo',
		'setting' => 'peti_care_slidephoneno'
	));	
	
	$wp_customize->add_setting('peti_care_show_phonebx_bottomonslider',array(
		'default' => false,
		'sanitize_callback' => 'peti_care_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));	 
	
	$wp_customize->add_control( 'peti_care_show_phonebx_bottomonslider', array(
	   'settings' => 'peti_care_show_phonebx_bottomonslider',
	   'section'   => 'peti_care_topcontactinfo',
	   'label'     => __('Check To show phone box bottom on slider','peti-care'),
	   'type'      => 'checkbox'
	 ));//Show Phone box Bottom on the slider
	
	 	
	//Homepage Slide Section		
	$wp_customize->add_section( 'peti_care_homeslide_sections', array(
		'title' => __('Homepage Slider Sections', 'peti-care'),
		'priority' => null,
		'description' => __('Default image size for slider is 1400 x 792 pixel.','peti-care'), 
		'panel' => 	'peti_care_optionspanel_settings',           			
    ));
	
	$wp_customize->add_setting('peti_care_homeslidepage1',array(
		'default' => '0',			
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'peti_care_sanitize_dropdown_pages'
	));
	
	$wp_customize->add_control('peti_care_homeslidepage1',array(
		'type' => 'dropdown-pages',
		'label' => __('Select page for slide 1:','peti-care'),
		'section' => 'peti_care_homeslide_sections'
	));	
	
	$wp_customize->add_setting('peti_care_homeslidepage2',array(
		'default' => '0',			
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'peti_care_sanitize_dropdown_pages'
	));
	
	$wp_customize->add_control('peti_care_homeslidepage2',array(
		'type' => 'dropdown-pages',
		'label' => __('Select page for slide 2:','peti-care'),
		'section' => 'peti_care_homeslide_sections'
	));	
	
	$wp_customize->add_setting('peti_care_homeslidepage3',array(
		'default' => '0',			
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'peti_care_sanitize_dropdown_pages'
	));
	
	$wp_customize->add_control('peti_care_homeslidepage3',array(
		'type' => 'dropdown-pages',
		'label' => __('Select page for slide 3:','peti-care'),
		'section' => 'peti_care_homeslide_sections'
	));	//frontpage Slider Section	
	
	//Slider Excerpt Length
	$wp_customize->add_setting( 'peti_care_excerpt_length_homeslide', array(
		'default'              => 0,
		'type'                 => 'theme_mod',		
		'sanitize_callback'    => 'peti_care_sanitize_excerptrange',		
	) );
	$wp_customize->add_control( 'peti_care_excerpt_length_homeslide', array(
		'label'       => __( 'Slider Excerpt length','peti-care' ),
		'section'     => 'peti_care_homeslide_sections',
		'type'        => 'range',
		'settings'    => 'peti_care_excerpt_length_homeslide','input_attrs' => array(
			'step'             => 1,
			'min'              => 0,
			'max'              => 50,
		),
	) );	
	
	$wp_customize->add_setting('peti_care_homeslidepage_btntext',array(
		'default' => null,
		'sanitize_callback' => 'sanitize_text_field'	
	));
	
	$wp_customize->add_control('peti_care_homeslidepage_btntext',array(	
		'type' => 'text',
		'label' => __('enter button name here','peti-care'),
		'section' => 'peti_care_homeslide_sections',
		'setting' => 'peti_care_homeslidepage_btntext'
	)); // slider read more button text
	
	$wp_customize->add_setting('peti_care_show_homeslide_sections',array(
		'default' => false,
		'sanitize_callback' => 'peti_care_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));	 
	
	$wp_customize->add_control( 'peti_care_show_homeslide_sections', array(
	    'settings' => 'peti_care_show_homeslide_sections',
	    'section'   => 'peti_care_homeslide_sections',
	    'label'     => __('Check To Show This Section','peti-care'),
	   'type'      => 'checkbox'
	 ));//Show Home Slide Settings	
	 
	 
	 //Welcome to Insurance Company Sections
	$wp_customize->add_section('peti_care_welcometoinsurer_section', array(
		'title' => __('Welcome to Insurance Company Sections','peti-care'),
		'description' => __('Select pages from the dropdown for Welcome to Insurance Company','peti-care'),
		'priority' => null,
		'panel' => 	'peti_care_optionspanel_settings',          
	));	
		
	$wp_customize->add_setting('peti_care_welcomepage',array(
		'default' => '0',			
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'peti_care_sanitize_dropdown_pages'
	));
 
	$wp_customize->add_control(	'peti_care_welcomepage',array(
		'type' => 'dropdown-pages',			
		'section' => 'peti_care_welcometoinsurer_section',
	));
	
	$wp_customize->add_setting('peti_care_secondtitle',array(
		'default' => null,
		'sanitize_callback' => 'sanitize_text_field'	
	));
	
	$wp_customize->add_control('peti_care_secondtitle',array(	
		'type' => 'text',
		'label' => __('Enter second title  text here','peti-care'),
		'section' => 'peti_care_welcometoinsurer_section',
		'setting' => 'peti_care_secondtitle'
	));	
		

	$wp_customize->add_setting( 'peti_care_welcomepage_excerpt_length', array(
		'default'              => 30,
		'type'                 => 'theme_mod',		
		'sanitize_callback'    => 'peti_care_sanitize_excerptrange',		
	) );
	$wp_customize->add_control( 'peti_care_welcomepage_excerpt_length', array(
		'label'       => __( 'page excerpt length','peti-care' ),
		'section'     => 'peti_care_welcometoinsurer_section',
		'type'        => 'range',
		'settings'    => 'peti_care_welcomepage_excerpt_length','input_attrs' => array(
			'step'             => 1,
			'min'              => 0,
			'max'              => 50,
		),
	) );
	
	$wp_customize->add_setting('peti_care_show_welcometoinsurer_section',array(
		'default' => false,
		'sanitize_callback' => 'peti_care_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));		
	
	$wp_customize->add_control( 'peti_care_show_welcometoinsurer_section', array(
	   'settings' => 'peti_care_show_welcometoinsurer_section',
	   'section'   => 'peti_care_welcometoinsurer_section',
	   'label'     => __('Check To Show This Section','peti-care'),
	   'type'      => 'checkbox'
	 ));//Show Welcome Sections
	 	 
	 
	 //Four page Services Sections
	$wp_customize->add_section('peti_care_4column_services_sections', array(
		'title' => __('Four Page Services Sections','peti-care'),
		'description' => __('Select pages from the dropdown for four column sections','peti-care'),
		'priority' => null,
		'panel' => 	'peti_care_optionspanel_settings',          
	));
	
	$wp_customize->add_setting('peti_care_lefttitle',array(
		'default' => null,
		'sanitize_callback' => 'sanitize_text_field'	
	));
	
	$wp_customize->add_control('peti_care_lefttitle',array(	
		'type' => 'text',
		'label' => __('Enter title text here','peti-care'),
		'section' => 'peti_care_4column_services_sections',
		'setting' => 'peti_care_lefttitle'
	));	
	
	$wp_customize->add_setting('peti_care_shortdescription',array(
		'default' => null,
		'sanitize_callback' => 'sanitize_text_field'	
	));
	
	$wp_customize->add_control('peti_care_shortdescription',array(	
		'type' => 'text',
		'label' => __('Enter short description here','peti-care'),
		'section' => 'peti_care_4column_services_sections',
		'setting' => 'peti_care_shortdescription'
	));	
		
		
	$wp_customize->add_setting('peti_care_4pagebx1',array(
		'default' => '0',			
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'peti_care_sanitize_dropdown_pages'
	));
 
	$wp_customize->add_control(	'peti_care_4pagebx1',array(
		'type' => 'dropdown-pages',			
		'section' => 'peti_care_4column_services_sections',
	));		
	
	$wp_customize->add_setting('peti_care_4pagebx2',array(
		'default' => '0',			
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'peti_care_sanitize_dropdown_pages'
	));
 
	$wp_customize->add_control(	'peti_care_4pagebx2',array(
		'type' => 'dropdown-pages',			
		'section' => 'peti_care_4column_services_sections',
	));
	
	$wp_customize->add_setting('peti_care_4pagebx3',array(
		'default' => '0',			
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'peti_care_sanitize_dropdown_pages'
	));
 
	$wp_customize->add_control(	'peti_care_4pagebx3',array(
		'type' => 'dropdown-pages',			
		'section' => 'peti_care_4column_services_sections',
	));	
	
	$wp_customize->add_setting('peti_care_4pagebx4',array(
		'default' => '0',			
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'peti_care_sanitize_dropdown_pages'
	));
 
	$wp_customize->add_control(	'peti_care_4pagebx4',array(
		'type' => 'dropdown-pages',			
		'section' => 'peti_care_4column_services_sections',
	));		

	$wp_customize->add_setting( 'peti_care_4column_excerpt_length', array(
		'default'              => 10,
		'type'                 => 'theme_mod',		
		'sanitize_callback'    => 'peti_care_sanitize_excerptrange',		
	) );
	$wp_customize->add_control( 'peti_care_4column_excerpt_length', array(
		'label'       => __( 'four page box excerpt length','peti-care' ),
		'section'     => 'peti_care_4column_services_sections',
		'type'        => 'range',
		'settings'    => 'peti_care_4column_excerpt_length','input_attrs' => array(
			'step'             => 1,
			'min'              => 0,
			'max'              => 50,
		),
	) );	
	
	$wp_customize->add_setting('peti_care_show_4column_services_sections',array(
		'default' => false,
		'sanitize_callback' => 'peti_care_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));		
	
	$wp_customize->add_control( 'peti_care_show_4column_services_sections', array(
	   'settings' => 'peti_care_show_4column_services_sections',
	   'section'   => 'peti_care_4column_services_sections',
	   'label'     => __('Check To Show This Section','peti-care'),
	   'type'      => 'checkbox'
	 ));//Show four page column sections
	 
		 
	 //Blog Posts Settings
	$wp_customize->add_panel( 'peti_care_blogsettings_panel', array(
		'priority' => 3,
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => __( 'Blog Posts Settings', 'peti-care' ),		
	) );
	
	$wp_customize->add_section('peti_care_blogmeta_options',array(
		'title' => __('Blog Meta Options','peti-care'),			
		'priority' => null,
		'panel' => 	'peti_care_blogsettings_panel', 	         
	));		
	
	$wp_customize->add_setting('peti_care_hide_blogdate',array(
		'sanitize_callback' => 'peti_care_sanitize_checkbox',
	));	 

	$wp_customize->add_control( 'peti_care_hide_blogdate', array(
    	'label' => __('Check to hide post date','peti-care'),	
		'section'   => 'peti_care_blogmeta_options', 
		'setting' => 'peti_care_hide_blogdate',		
    	'type'      => 'checkbox'
     )); //Blog Post Date
	 
	 
	 $wp_customize->add_setting('peti_care_hide_postcats',array(
		'sanitize_callback' => 'peti_care_sanitize_checkbox',
	));	 

	$wp_customize->add_control( 'peti_care_hide_postcats', array(
		'label' => __('Check to hide post category','peti-care'),	
    	'section'   => 'peti_care_blogmeta_options',		
		'setting' => 'peti_care_hide_postcats',		
    	'type'      => 'checkbox'
     )); //blog Posts category	 
	 
	 
	 $wp_customize->add_section('peti_care_postfeatured_image',array(
		'title' => __('Posts Featured image','peti-care'),			
		'priority' => null,
		'panel' => 	'peti_care_blogsettings_panel', 	         
	));		
	
	$wp_customize->add_setting('peti_care_hide_postfeatured_image',array(
		'sanitize_callback' => 'peti_care_sanitize_checkbox',
	));	 

	$wp_customize->add_control( 'peti_care_hide_postfeatured_image', array(
		'label' => __('Check to hide post featured image','peti-care'),
    	'section'   => 'peti_care_postfeatured_image',		
		'setting' => 'peti_care_hide_postfeatured_image',	
    	'type'      => 'checkbox'
     )); //Posts featured image
	 
	 
	 $wp_customize->add_setting('peti_care_featuredimg_left',array(
		'sanitize_callback' => 'peti_care_sanitize_checkbox',
	));	 

	$wp_customize->add_control( 'peti_care_featuredimg_left', array(
		'label' => __('Check to featured image Left Side','peti-care'),
    	'section'   => 'peti_care_postfeatured_image',		
		'setting' => 'peti_care_featuredimg_left',	
    	'type'      => 'checkbox'
     )); //posts featured Left
	 
	  
	 $wp_customize->add_section('peti_care_bloglearnmorebtn',array(
		'title' => __('Posts Read More Button','peti-care'),			
		'priority' => null,
		'panel' => 	'peti_care_blogsettings_panel', 	         
	 ));	
	 
	 $wp_customize->add_setting('peti_care_bloglearnmorebuttontext',array(
		'default' => null,
		'sanitize_callback' => 'sanitize_text_field'	
	)); //blog read more button text
	
	$wp_customize->add_control('peti_care_bloglearnmorebuttontext',array(	
		'type' => 'text',
		'label' => __('Read more button text for blog posts','peti-care'),
		'section' => 'peti_care_bloglearnmorebtn',
		'setting' => 'peti_care_bloglearnmorebuttontext'
	)); //Blog Post read more button text	
	
	$wp_customize->add_section('peti_care_blogpost_content_settings',array(
		'title' => __('Posts Excerpt Options','peti-care'),			
		'priority' => null,
		'panel' => 	'peti_care_blogsettings_panel', 	         
	 ));	 
	 
	$wp_customize->add_setting( 'peti_care_blogexcerptrange', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'peti_care_sanitize_excerptrange',		
	) );
	
	$wp_customize->add_control( 'peti_care_blogexcerptrange', array(
		'label'       => __( 'Excerpt length','peti-care' ),
		'section'     => 'peti_care_blogpost_content_settings',
		'type'        => 'range',
		'settings'    => 'peti_care_blogexcerptrange','input_attrs' => array(
			'step'             => 1,
			'min'              => 0,
			'max'              => 50,
		),
	) );

    $wp_customize->add_setting('peti_care_blogfullcontent',array(
        'default' => 'Excerpt',     
        'sanitize_callback' => 'peti_care_sanitize_choices'
	));
	
	$wp_customize->add_control('peti_care_blogfullcontent',array(
        'type' => 'select',
        'label' => __('Posts Content','peti-care'),
        'section' => 'peti_care_blogpost_content_settings',
        'choices' => array(
        	'Content' => __('Content','peti-care'),
            'Excerpt' => __('Excerpt','peti-care'),
            'No Content' => __('No Excerpt','peti-care')
        ),
	) ); 
	
	
	$wp_customize->add_section('peti_care_postsinglemeta',array(
		'title' => __('Posts Single Settings','peti-care'),			
		'priority' => null,
		'panel' => 	'peti_care_blogsettings_panel', 	         
	));	
	
	$wp_customize->add_setting('peti_care_hide_postdate_fromsingle',array(
		'sanitize_callback' => 'peti_care_sanitize_checkbox',
	));	 

	$wp_customize->add_control( 'peti_care_hide_postdate_fromsingle', array(
    	'label' => __('Check to hide post date from single','peti-care'),	
		'section'   => 'peti_care_postsinglemeta', 
		'setting' => 'peti_care_hide_postdate_fromsingle',		
    	'type'      => 'checkbox'
     )); //Hide Posts date from single
	 
	 
	 $wp_customize->add_setting('peti_care_hide_postcats_fromsingle',array(
		'sanitize_callback' => 'peti_care_sanitize_checkbox',
	));	 

	$wp_customize->add_control( 'peti_care_hide_postcats_fromsingle', array(
		'label' => __('Check to hide post category from single','peti-care'),	
    	'section'   => 'peti_care_postsinglemeta',		
		'setting' => 'peti_care_hide_postcats_fromsingle',		
    	'type'      => 'checkbox'
     )); //Hide blogposts category single
	 
	 
	 //Sidebar Settings
	$wp_customize->add_section('peti_care_sidebarsettings', array(
		'title' => __('Sidebar Settings','peti-care'),		
		'priority' => null,
		'panel' => 	'peti_care_blogsettings_panel',          
	));		
	 
	$wp_customize->add_setting('peti_care_hidesidebar_blogposts',array(
		'default' => false,
		'sanitize_callback' => 'peti_care_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));	 
	
	$wp_customize->add_control( 'peti_care_hidesidebar_blogposts', array(
	   'settings' => 'peti_care_hidesidebar_blogposts',
	   'section'   => 'peti_care_sidebarsettings',
	   'label'     => __('Check to show sidebar from homepage','peti-care'),
	   'type'      => 'checkbox'
	 ));//show sidebar blog posts 
	
		 
}
add_action( 'customize_register', 'peti_care_customize_register' );

function peti_care_custom_css(){ 
?>
	<style type="text/css"> 					
        a,
        #sidebar ul li a:hover,
		#sidebar ol li a:hover,							
        .article-Listing h3 a:hover,
		.site-footer ul li a:hover, 
		.site-footer ul li.current_page_item a,		
        .postmeta a:hover,
		.grid4BX a.more-bgbtn:after,
		.aboutliststyle ul li::before,
		h4.sub_title,
		.quotebtn h4 a:hover,
		.welcome-rightBX h3,
		.grid4BX:hover h4 a,			 			
        .button:hover,
		h2.services_title span,			
		.blog-postmeta a:hover,
		.blog-postmeta a:focus,
		blockquote::before	
            { color:<?php echo esc_html( get_theme_mod('peti_care_colorscheme','#91c330')); ?>;}					 
            
        .pagination ul li .current, .pagination ul li a:hover, 
        #commentform input#submit:hover,
		.slidePhoneSt,
		.sixcirclecolumn:hover .thumbbx,
		.grid4BX:hover a.more-bgbtn:after,
        .nivo-controlNav a.active,
		.sd-search input, .sd-top-bar-nav .sd-search input,			
		a.blogreadmore,
		.hdr-topstrip,
		.copyrigh-wrapper:before,										
        #sidebar .search-form input.search-submit,				
        .wpcf7 input[type='submit'],				
        nav.pagination .page-numbers.current,		
		.morebutton,	
		.nivo-directionNav a:hover,	
		.nivo-caption .slidermorebtn:hover		
            { background-color:<?php echo esc_html( get_theme_mod('peti_care_colorscheme','#91c330')); ?>;}
			

		
		.tagcloud a:hover,
		.logo::after,
		blockquote
            { border-color:<?php echo esc_html( get_theme_mod('peti_care_colorscheme','#91c330')); ?>;}
			
		.sixcirclecolumn:hover .thumbbx:before
            { border-top-color:<?php echo esc_html( get_theme_mod('peti_care_colorscheme','#91c330')); ?>;}				
			
		#SiteWrapper a:focus,
		input[type="date"]:focus,
		input[type="search"]:focus,
		input[type="number"]:focus,
		input[type="tel"]:focus,
		input[type="button"]:focus,
		input[type="month"]:focus,
		button:focus,
		input[type="text"]:focus,
		input[type="email"]:focus,
		input[type="range"]:focus,		
		input[type="password"]:focus,
		input[type="datetime"]:focus,
		input[type="week"]:focus,
		input[type="submit"]:focus,
		input[type="datetime-local"]:focus,		
		input[type="url"]:focus,
		input[type="time"]:focus,
		input[type="reset"]:focus,
		input[type="color"]:focus,
		textarea:focus
            { border:1px solid <?php echo esc_html( get_theme_mod('peti_care_colorscheme','#91c330')); ?>;}	
			
		
		.site-navigation a,
		.site-navigation ul li.current_page_parent ul.sub-menu li a,
		.site-navigation ul li.current_page_parent ul.sub-menu li.current_page_item ul.sub-menu li a,
		.site-navigation ul li.current-menu-ancestor ul.sub-menu li.current-menu-item ul.sub-menu li a  			
            { color:<?php echo esc_html( get_theme_mod('peti_care_menufontcolor','#333333')); ?>;}	
			
		
		.site-navigation ul.nav-menu .current_page_item > a,
		.site-navigation ul.nav-menu .current-menu-item > a,
		.site-navigation ul.nav-menu .current_page_ancestor > a,
		.site-navigation ul.nav-menu .current-menu-ancestor > a, 
		.site-navigation .nav-menu a:hover,
		.site-navigation .nav-menu a:focus,
		.site-navigation .nav-menu ul a:hover,
		.site-navigation .nav-menu ul a:focus,
		.site-navigation ul li a:hover, 
		.site-navigation ul li.current-menu-item a,			
		.site-navigation ul li.current_page_parent ul.sub-menu li.current-menu-item a,
		.site-navigation ul li.current_page_parent ul.sub-menu li a:hover,
		.site-navigation ul li.current-menu-item ul.sub-menu li a:hover,
		.site-navigation ul li.current-menu-ancestor ul.sub-menu li.current-menu-item ul.sub-menu li a:hover 		 			
            { color:<?php echo esc_html( get_theme_mod('peti_care_menufontactivecolor','#91c330')); ?>;}
			
		.hdrtopcart .cart-count
            { background-color:<?php echo esc_html( get_theme_mod('peti_care_menufontactivecolor','#91c330')); ?>;}		
			
		#SiteWrapper .site-navigation a:focus		 			
            { border:1px solid <?php echo esc_html( get_theme_mod('peti_care_menufontactivecolor','#91c330')); ?>;}	
	
    </style> 
<?php                                                                                                                                                                                          
}
         
add_action('wp_head','peti_care_custom_css');	 

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function peti_care_customize_preview_js() {
	wp_enqueue_script( 'peti_care_customizer', get_template_directory_uri() . '/js/customize-preview.js', array( 'customize-preview' ), '19062019', true );
}
add_action( 'customize_preview_init', 'peti_care_customize_preview_js' );